@@ -10,7 +10,7 @@
     :license: BSD, see LICENSE for more details.
 """
 
-nodeenv_version = '0.9.4'
+nodeenv_version = '0.9.5'
 
 import sys
 import os
@@ -540,9 +540,14 @@ def install_activate(env_dir, opt):
     if opt.node == "system":
         env = os.environ.copy()
         env.update({'PATH': remove_env_bin_from_path(env['PATH'], bin_dir)})
-        which_node_output, _ = subprocess.Popen(
-            ["which", "node"], stdout=subprocess.PIPE, env=env).communicate()
-        shim_node = clear_output(which_node_output)
+        for candidate in ("nodejs", "node"):
+            which_node_output, _ = subprocess.Popen(
+                ["which", candidate],
+                stdout=subprocess.PIPE, env=env).communicate()
+            shim_node = clear_output(which_node_output)
+            if shim_node:
+                break
+        assert shim_node, "Did not find nodejs or node system executable"
 
     for name, content in files.items():
         file_path = join(bin_dir, name)
@@ -562,6 +567,8 @@ def install_activate(env_dir, opt):
         writefile(file_path, content, append=need_append)
         os.chmod(file_path, mode_0755)
 
+    os.symlink("node", join(bin_dir, "nodejs"))
+
 
 def create_environment(env_dir, opt):
     """
@@ -675,7 +682,7 @@ unset NODE_VIRTUAL_ENV_DISABLE_PROMPT
 SHIM = """#!/usr/bin/env bash
 export NODE_PATH=__NODE_VIRTUAL_ENV__/lib/node_modules
 export NPM_CONFIG_PREFIX=__NODE_VIRTUAL_ENV__
-exec __SHIM_NODE__ $*
+exec __SHIM_NODE__ "$@"
 """
 
 ACTIVATE_SH = """
@@ -720,14 +727,18 @@ deactivate_node () {
 }
 
 freeze () {
-    NPM_VER=`npm -v | cut -d '.' -f 1`
+    local NPM_VER=`npm -v | cut -d '.' -f 1`
+    local re="[a-zA-Z0-9\.\-]+@[0-9]+\.[0-9]+\.[0-9]+([\+\-][a-zA-Z0-9\.\-]+)*"
     if [ "$NPM_VER" != '1' ]; then
         NPM_LIST=`npm list installed active 2>/dev/null | \
                   cut -d ' ' -f 1 | grep -v npm`
     else
-        NPM_LIST=`npm ls -g | grep -E '^.{4}\w{1}' | \
-                 grep -o -E '[a-zA-Z0-9\.\-]+@[0-9]+\.[0-9]+\.[0-9]+([\+\-][a-zA-Z0-9\.\-]+)*' | \
-                 grep -v npm`
+        local npmls="npm ls -g"
+        if [ "$1" = "-l" ]; then
+            npmls="npm ls"
+            shift
+        fi
+        NPM_LIST=$($npmls| grep -E '^.{4}\w{1}'| grep -o -E "$re"| grep -v npm)
     fi
 
     if [ -z "$@" ]; then
